#!/usr/bin/env python3
import sys
import json
import urllib.request
import urllib.parse
from typing import Dict, Any

class Translator:
    def __init__(self):
        self.base_url = "https://translate.googleapis.com/translate_a/single"
        self.user_agent = ('Mozilla/5.0 (Windows NT 10.0; Win64; x64) '
                          'AppleWebKit/537.36 (KHTML, like Gecko) '
                          'Chrome/120.0.0.0 Safari/537.36')

    def translate(self, text: str, target_lang: str, source_lang: str = 'auto') -> Dict[str, Any]:
        try:
            params = {
                'client': 'gtx',
                'sl': source_lang,
                'tl': target_lang,
                'dt': 't',
                'q': text
            }
            
            url = f"{self.base_url}?{urllib.parse.urlencode(params)}"
            request = urllib.request.Request(
                url,
                headers={'User-Agent': self.user_agent}
            )
            
            with urllib.request.urlopen(request) as response:
                if response.status != 200:
                    return {
                        "success": False,
                        "error": f"HTTP Error: {response.status}"
                    }
                
                raw_data = response.read().decode('utf-8')
                data = json.loads(raw_data)
                
                translated_text = ''.join(part[0] for part in data[0] if part[0])
                
                return {
                    "success": True,
                    "translated_text": translated_text,
                    "source_text": text,
                    "target_lang": target_lang,
                    "detected_lang": data[2] if len(data) > 2 else 'unknown'
                }
                
        except Exception as e:
            return {
                "success": False,
                "error": str(e)
            }

def main():
    if len(sys.argv) < 3:
        print(json.dumps({
            "success": False,
            "error": "Usage: translator.py <text> <target_lang> [source_lang]"
        }))
        sys.exit(1)
    
    try:
        text = sys.argv[1]
        target_lang = sys.argv[2].lower()
        source_lang = sys.argv[3].lower() if len(sys.argv) > 3 else 'auto'
        
        translator = Translator()
        result = translator.translate(text, target_lang, source_lang)
        
        print(json.dumps(result, ensure_ascii=False))
        
    except Exception as e:
        print(json.dumps({
            "success": False,
            "error": str(e)
        }))
        sys.exit(1)

if __name__ == "__main__":
    main()